// Server.java

import java.util.*;

class AccountImpl extends Bank._AccountImplBase {
  AccountImpl(float balance) {
    _balance = balance;
  }
  public float balance() {
    return _balance;
  }
  private float _balance;
}

class AccountManagerImpl extends Bank._AccountManagerImplBase {
  AccountManagerImpl(String name) {
    super(name);
  }
  public synchronized Bank.Account open(String name) {
    // Lookup the account in the account dictionary.
    Bank.Account account = (Bank.Account) _accounts.get(name);
    if(account == null) {
      // Create a new account with between 0 and 1000 dollars.
      float balance = Math.abs(_random.nextInt()) % 100000 / 100f;
      account = new AccountImpl(balance);
      System.out.println("Created " + name + "'s account: " + account);
      // Export the new object reference.
      _boa().obj_is_ready(account);
      // Save the account in the account dictionary.
      _accounts.put(name, account);
    }
    // Return the account.
    return account;
  }
  private Dictionary _accounts = new Hashtable();
  private Random _random = new Random();
}

public class Server {

  public static void main(String[] args) {
    if(args.length == 0) {
      System.out.println( "Usage: vbj Server URL_IOR");
      return;
    }
    String ior = args[0];
    try {
      // Initialize the ORB.
      org.omg.CORBA.ORB orb = org.omg.CORBA.ORB.init(args,null);
      // Initialize the BOA.
      org.omg.CORBA.BOA boa = orb.BOA_init();
      // Create the account manager object.
      AccountManagerImpl manager = new AccountManagerImpl("BankManager");
      // Export the newly create object.
      boa.obj_is_ready(manager);
      System.out.println(manager + " is ready.");
      // Register URL-type name
      com.visigenic.vbroker.URLNaming.Resolver resolver = 
	com.visigenic.vbroker.URLNaming.ResolverHelper.narrow(
	    orb.resolve_initial_references("URLNamingResolver"));
      // Use force_register to overwrite the ior_file 
      resolver.force_register_url(ior, manager);
      // Wait for incoming requests
      boa.impl_is_ready();
    }
    catch(Exception e) {
      System.err.println(e);
    }
  }

}
