// Server.java

import java.io.*;

public class Server {

  public static void main(String[] args) {
    // Initialize the ORB.
    org.omg.CORBA.ORB orb = org.omg.CORBA.ORB.init(args,null);
    // Create the account manager object.
    Bank.AccountManager manager = new AccountManagerImpl();
    // Export the newly create object.
    orb.connect(manager);

    // Write the AccountManager's IOR to a file, so clients can access it.
    try {
      FileWriter output = new FileWriter("bank.ior");
      output.write(orb.object_to_string(manager));
      output.close();
      System.out.println("Wrote Account Manager's IOR to file: bank.ior");
    }
    catch(java.io.IOException e) {
      System.out.println("Exception: " + e);
      System.exit(1);
    }

    System.out.println(manager + " is ready.");

    // It is the ORB's responsibility to create threads to receive requests.
    // there is no need to enter an event loop, so just block forever.
    //
    // In this example, we will join with our own thread.  However, there
    // are many different ways of doing this.  If your application uses
    // the AWT this step may not be necessary since AWT threads are not
    // daemon threads.

    try {
      Thread.currentThread().join();
    }
    catch(InterruptedException e) {
      System.out.println(e);
    }
  }

}

